﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Web;
using System.Xml.Serialization;

namespace FlexGridIntro.Models
{

    /// <summary>
    /// class to Convert XML nodes to List Object
    /// </summary>
    public class Food
    {
        [XmlElement("name")]
        public string Name { get; set; }
        [XmlElement("price")]
        public double Price { get; set; }
        [XmlElement("description")]
        public string Description { get; set; }
        [XmlElement("calories")]
        public int Calories { get; set; }
    }
    /// <summary>
    /// Class to fetch Data from RootNode in XML file
    /// </summary>
    [XmlRoot("breakfast_menu")]
    public class BreakFastMenu
    {
        [XmlElement("food",typeof(Food))]
        public List<Food> FoodMenu { get; set; }
    }
    public class XMLData
    {
        /// <summary>
        /// Fetch Data from the XML file
        /// </summary>
        /// <param name="path">Location of XML file to fetch the Data</param>
        /// <returns>Return the List of Food</returns>
        public static List<Food> GetBreakFastMenus(string path)
        {
            using (StreamReader reader = new StreamReader(path))
            {
                XmlSerializer serializer = new XmlSerializer(typeof(BreakFastMenu));
                BreakFastMenu menu = (BreakFastMenu)serializer.Deserialize(reader);
                return menu.FoodMenu;
            }
        }
    }
}